package com.ruoyi.post.frequency.postlike.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.post.controller.req.PostLikeReq;
import com.ruoyi.post.frequency.postlike.entity.PostLike;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 帖子点赞Service接口
 * 
 * @author liwenlong
 * @date 2023-10-09
 */
public interface PostLikeService extends IService<PostLike>
{
    /**
     * 查询帖子点赞
     * 
     * @param id 帖子点赞主键
     * @return 帖子点赞
     */
    public PostLike selectPostLikeById(Long id);

    /**
     * 查询帖子点赞列表
     * 
     * @param postLike 帖子点赞
     * @return 帖子点赞集合
     */
    public List<PostLike> selectPostLikeList(PostLike postLike);

    /**
     * 新增帖子点赞
     * 
     * @param postLike 帖子点赞
     * @return 结果
     */
    public int insertPostLike(PostLike postLike);

    /**
     * 修改帖子点赞
     * 
     * @param postLike 帖子点赞
     * @return 结果
     */
    public int updatePostLike(PostLike postLike);

    /**
     * 批量删除帖子点赞
     * 
     * @param ids 需要删除的帖子点赞主键集合
     * @return 结果
     */
    public int deletePostLikeByIds(Long[] ids);

    /**
     * 删除帖子点赞信息
     * 
     * @param id 帖子点赞主键
     * @return 结果
     */
    public int deletePostLikeById(Long id);

    /**
     * 帖子点赞
     * @param req
     * @param userVo
     * @return
     */
    ResponseData postLike(PostLikeReq req, UserVo userVo);
}
